package ch.vorburger.jpapattern.framework;

import ch.vorburger.jpapattern.framework.aop.NullEntityFactory;

/**
 * Marker interface for a "null Entity".
 * 
 * Such an object is used to represent a non-existent entity pointed to by a
 * NULL foreign key in another entity. The purpose is to allow entity traversal
 * for ID retrieval avoiding NullPointerExceptions.
 * 
 * All it's getters for relationships return other NullEntity instances, all
 * it's getters for non-primitive basic fields return null, all it's setters
 * throw an UnsupportedOperationException.
 *
 * NullEntity implementations can be either coded (hand written or generated),
 * or obtained from the NullEntityFactory.  
 * 
 * @see Null
 * @see NullEntityFactory
 * 
 * @author Michael Vorburger
 */
public interface NullEntity extends Null {

	String UOE_MSG = " Entity does not support setters, as it represents NULL, please create a new Entity and set it into the owning class before accessing field: ";
}
