package ch.vorburger.jpapattern.framework;


/**
 * Marker interface for a "Nullable Objects".
 * 
 * Classes implementing Nullable may be represented by instances that are subclasses of those classes but implement {@link Null}.
 *
 * Classes implementing Null must override {@link Nullable#isNull()} to return false, unless they are the {@link Null}.
 *
 * @see Null
 * @see http://en.wikipedia.org/wiki/Null_Object_pattern
 */
public interface Nullable {

	/**
	 * Check if this is a null object.
	 * Alternatively, if (obj instanceof Null) may also be used.
	 * 
	 * @return is this instance a null object?
	 */
	boolean isNull();
	
}
