package ch.vorburger.jpapattern.sample.entities;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.PostLoad;
import javax.persistence.Table;

import ch.vorburger.jpapattern.framework.JPAHelper;
import ch.vorburger.jpapattern.framework.Nullable;
import ch.vorburger.jpapattern.framework.aop.NullEntityFactory;

/**
 * Sample JPA Entity.
 * 
 * @author Michael Vorburger
 */
@Entity
@Table(name = "test_complex")
public class AEntity implements Nullable {

    @Id
    @Column(nullable = false)
    private Long id;

    @ManyToOne(cascade = CascadeType.ALL, fetch = FetchType.LAZY, optional = true)
    @JoinColumn(nullable = true, name = "c_id") // NOTE: This one CAN be NULL
    private BEntity b;
    

    public Long getId() {
        return id;
    }

    public BEntity getB() {
    	// Need to check if c is null, and return a null object if it is.
    	// We can either use a hand-coded (or code generated) class like the NullCEntity, like this:
        //    return (c != null) ? c : NullCEntity.NULL; // sic!
    	// or the NullEntityFactory like this:
        return (b != null) ? b : NullEntityFactory.theNullObject(BEntity.class); 
    }

    public void setB(BEntity _b) {
        this.b = _b;
    }

    @PostLoad
    @SuppressWarnings("unused") // private and called by JPA implementation only, never by user code
    private void initRefs() {
    	if (!JPAHelper.OPENJPA.isFieldLoaded(this, "b")) // can NOT use (c == null), as that would lazy load! 
        	b = JPAHelper.OPENJPA.getReference(this, "b", BEntity.class); // voilà!

        // NOTE: Fields with @Id (if any), do not have to be set, because they already have a Reference, always (in OpenJPA) 
    }

	/* (non-Javadoc)
	 * @see ch.vorburger.jpapattern.framework.Nullable#isNull()
	 */
	@Override
	public boolean isNull() {
		return false;
	}
}
